Function inspect_my_xp

pub fn inspect_my_xp<T: Config<I>, I: 'static>(xp_id: XpId<T>)
Query the liquid XP balance for an owned XP key.

Origin: Signed user (must be the XP key owner)

This extrinsic allows the owner of an XP key to query the current liquid XP balance associated with that key.

Emits Event::Xp with the XP key and the current liquid XP balance.

Note: This extrinsic is compiled only when the dev feature is enabled. It is completely excluded from the runtime when dev is not enabled, and therefore is not available in production builds.

Warning: Doc-Only

This function is an automatically generated, and is doc-only, uncallable stub. See the real version in [Pallet::inspect_my_xp].