pub fn call<T: Config<I>, I: 'static>(
xp_id: XpId<T>,
call: Box<<T as Config<I>>::RuntimeCall>,
)Expand description
Executes a runtime call using an XP identity as the origin.
Origin: Signed (must be the owner of the XP identity)
This extrinsic allows the owner of an XP identity to dispatch a call on its behalf. While an XP identity is not a native account, it can act as a logical origin for execution through owner authorization.
The caller must be the registered owner of the given xp_id.
Upon successful verification, the provided call is dispatched
with the XP identity as the signed origin.
Warning: Doc-Only
This function is an automatically generated, and is doc-only, uncallable
stub. See the real version in
Pallet::call.