pub fn dispose<T: Config<I>, I: 'static>(owner: T::AccountId, xp_id: XpId<T>)Expand description
Dispose (Reap) an XP key.
Origin: Signed user
This extrinsic allows any signed account to finalize and remove XP entries that are no longer valid.
For an XP key, it checks:
- The key exists in storage,
- The key is considered “dead” (does not meet minimum timestamp requirements),
- The key has no active locks.
If all checks pass, the XP entry is reaped (removed from storage and blacklisted).
Emits Event::XpReap with each successfully reaped XP key.
Warning: Doc-Only
This function is an automatically generated, and is doc-only, uncallable
stub. See the real version in
Pallet::dispose.