pub fn force_handover<T: Config<I>, I: 'static>(
owner: T::AccountId,
xp_id: XpId<T>,
new_owner: T::AccountId,
)Expand description
Force transfer/handover ownership of an XP key to another account.
Origin: Root only
This extrinsic allows the current owner of an XP key to transfer ownership to another account. The call will fail if the destination account is already the owner or if the caller does not own the XP key.
On success, ownership of the XP key is transferred to the target account and an event is emitted.
Emits Event::XpOwner with the XP key and new owner.
Warning: Doc-Only
This function is an automatically generated, and is doc-only, uncallable
stub. See the real version in
Pallet::force_handover.