pub fn inspect_xp_keys_of<T: Config<I>, I: 'static>(owner: T::AccountId)Expand description
Emit a snapshot of all XpId’s currently owned by the specified account.
Origin: Signed user
This extrinsic reads the current ownership mapping for owner
and emits a single Event::XpOfOwner containing the complete
list of XpIds associated with that account at the time of execution.
Note: This extrinsic is compiled only when the dev feature is enabled.
It is completely excluded from the runtime when dev is not enabled,
and therefore is not available in production builds.
Warning: Doc-Only
This function is an automatically generated, and is doc-only, uncallable
stub. See the real version in
[Pallet::inspect_xp_keys_of].